#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity-property
version:              0.5.0.1
visibility:           public
id:                   genvalidity-property-0.5.0.1-99XUzp69CK4H51ZwCCF0vo
key:                  genvalidity-property-0.5.0.1-99XUzp69CK4H51ZwCCF0vo
license:              MIT
copyright:            Copyright: (c) 2016-2018 Tom Sydney Kerckhove
maintainer:
    syd.kerckhove@gmail.com,
    nick.van.den.broeck666@gmail.com

author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard properties for functions on `Validity` types
description:          Standard properties for functions on `Validity` types
category:             Testing
abi:                  76448af05e05d0faba2a974273d3c311
exposed:              True
exposed-modules:
    Test.Validity.Functions Test.Validity.Functions.CanFail
    Test.Validity.Functions.Equivalence
    Test.Validity.Functions.Idempotence Test.Validity.Functions.Inverse
    Test.Validity.Functions.Validity Test.Validity.GenValidity.Property
    Test.Validity.Operations Test.Validity.Operations.Associativity
    Test.Validity.Operations.Commutativity
    Test.Validity.Operations.Identity Test.Validity.Property
    Test.Validity.Property.Utils Test.Validity.Relations
    Test.Validity.Relations.Antireflexivity
    Test.Validity.Relations.Antisymmetry
    Test.Validity.Relations.Reflexivity
    Test.Validity.Relations.Symmetry
    Test.Validity.Relations.Transitivity
    Test.Validity.Shrinking.Property Test.Validity.Types

hidden-modules:       Paths_genvalidity_property
import-dirs:          /usr/lib/ghc-8.10.5/site-local/genvalidity-property-0.5.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/genvalidity-property-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/genvalidity-property-0.5.0.1

hs-libraries:         HSgenvalidity-property-0.5.0.1-99XUzp69CK4H51ZwCCF0vo
depends:
    QuickCheck-2.14.2-AlBcjlnVb6HBYuJ8lOviFD base-4.14.2.0
    genvalidity-0.11.0.0-9KAkxzoqH3HDdd7O93ZkVX
    hspec-2.8.2-HsNEIXhYrouFTll0mN5G5C
    pretty-show-1.10-jI5AqYpLoz98dMARTaePi
    validity-0.11.0.0-GTJUodvLvdUKLjUsjTcjDu

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-property/html/genvalidity-property.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-property/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

